@@ -247,8 +247,7 @@ class TyphosLoading(QtWidgets.QLabel):
         self._animation.setScaledSize(self._icon_size)
 
 
-class TyphosBase(QWidget):
-    """Base widget for all Typhos widgets that interface with devices"""
+class TyphosObject:
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.devices = list()
@@ -298,6 +297,11 @@ class TyphosBase(QWidget):
         return instance
 
 
+class TyphosBase(TyphosObject, QWidget):
+    """Base widget for all Typhos widgets that interface with devices"""
+    pass
+
+
 def make_identifier(name):
     """Make a Python string into a valid Python identifier"""
     # That was easy
